==> terragrunt-generator-0.7.0.tar.gz: terragrunt-generator-0.7.0/generator/main.py <==
import argparse
from distutils.dir_util import copy_tree
from tempfile import gettempdir
from uuid import uuid4

from generator import __version__
from generator.generate import generate
from generator.git import clone
from generator.reader import read_directory
from generator.utils import is_local

parser = argparse.ArgumentParser(
    prog='terragrunt-gernerator',
    description='generate terragrunt.hcl confirugation' + ' from terraform module',
)

parser.add_argument(
    '-V',
    action='version',
    version=f'%(prog)s {__version__}',
)

parser.add_argument('-u', '--url', required=True, help='the module repository url')

parser.add_argument('-v', '--version', help='the module version to use', default='main')

parser.add_argument('-p', '--path', help='define the module path if needed')

parser.add_argument(
    '--include',
    help='do no rendering the include block',
    action=argparse.BooleanOptionalAction,
    default=True,
)

parser.add_argument(
    '-l',
    '--lookup',
    help='define the lookup path'
    # , default='["{name}"]'
)


def main(args=None):
    args = parser.parse_args(args)

    tempdir = f'{gettempdir()}/{uuid4()}'

    if is_local(args.url):
        copy_tree(args.url, tempdir)
    else:
        clone(args.url, tempdir, args.version)

    hcl_files: list = read_directory(
        f"{tempdir}/{'' if args.path is None else args.path}"
    )

    output: str = generate(
        args.url,
        None if args.path is None else args.path,
        args.version,
        args.lookup,
        hcl_files,
        args.include,
    )

    print(output)

==> terragrunt-generator-0.7.4.tar.gz: terragrunt-generator-0.7.4/generator/main.py <==
import argparse
from distutils.dir_util import copy_tree
from tempfile import gettempdir
from uuid import uuid4

from generator import __version__
from generator.generate import generate
from generator.git import clone
from generator.reader import read_directory
from generator.utils import is_local

parser = argparse.ArgumentParser(
    prog='terragrunt-gernerator',
    description='generate terragrunt.hcl confirugation' + ' from terraform module',
)

parser.add_argument(
    '-V',
    action='version',
    version=f'%(prog)s {__version__}',
)

parser.add_argument('-u', '--url', required=True, help='the module repository url')

parser.add_argument('-v', '--version', help='the module version to use', default='main')

parser.add_argument('-p', '--path', help='define the module path if needed')

parser.add_argument(
    '--include',
    help='do no rendering the include block',
    action=argparse.BooleanOptionalAction,
    default=True,
)

parser.add_argument('-l', '--lookup', help='define the lookup path')


def create_working_directory() -> str:
    tempdir = f'{gettempdir()}/{uuid4()}'
    return tempdir


def copy_terraform_module(url: str, version: str, path: str):
    if is_local(url):
        copy_tree(url, path)
    else:
        clone(url, path, version)


def main(args=None):
    args: map = parser.parse_args(args)

    tempdir: str = create_working_directory()

    copy_terraform_module(args.url, args.version, tempdir)

    hcl_files: dict = read_directory(
        f"{tempdir}/{'' if args.path is None else args.path}"
    )

    output: str = generate(
        args.url,
        None if args.path is None else args.path,
        args.version,
        args.lookup,
        hcl_files,
        args.include,
    )

    print(output)
